[Mlir-commits] [mlir] 070bc9c - [MLIR][Presburger][NFC] Fix clang-tidy warnings

llvmlistbot at llvm.org llvmlistbot at llvm.org
Fri Feb 4 22:51:05 PST 2022


Author: Groverkss
Date: 2022-02-05T11:59:21+05:30
New Revision: 070bc9c1fbc4db06fa3e55fa47682bb8f4f26a6f

URL: https://github.com/llvm/llvm-project/commit/070bc9c1fbc4db06fa3e55fa47682bb8f4f26a6f
DIFF: https://github.com/llvm/llvm-project/commit/070bc9c1fbc4db06fa3e55fa47682bb8f4f26a6f.diff

LOG: [MLIR][Presburger][NFC] Fix clang-tidy warnings

This patch changes variable naming to lowerCamelCase to remove
clang-tidy warning in Presburger/Utils.cpp.

Added: 
    

Modified: 
    mlir/lib/Analysis/Presburger/Utils.cpp

Removed: 
    


################################################################################
diff  --git a/mlir/lib/Analysis/Presburger/Utils.cpp b/mlir/lib/Analysis/Presburger/Utils.cpp
index 7dc7a26e0b5c..39383f7af27d 100644
--- a/mlir/lib/Analysis/Presburger/Utils.cpp
+++ b/mlir/lib/Analysis/Presburger/Utils.cpp
@@ -160,14 +160,14 @@ static LogicalResult getDivRepr(const IntegerPolyhedron &cst, unsigned pos,
 
   // Extract divisor, the divisor can be negative and hence its sign information
   // is stored in `signDiv` to reverse the sign of dividend's coefficients.
-  // Equality must involve the pos-th variable and hence `temp_div` != 0.
-  int64_t temp_div = cst.atEq(eqInd, pos);
-  if (temp_div == 0)
+  // Equality must involve the pos-th variable and hence `tempDiv` != 0.
+  int64_t tempDiv = cst.atEq(eqInd, pos);
+  if (tempDiv == 0)
     return failure();
-  int64_t signDiv = temp_div < 0 ? -1 : 1;
+  int64_t signDiv = tempDiv < 0 ? -1 : 1;
 
   // The divisor is always a positive integer.
-  divisor = temp_div * signDiv;
+  divisor = tempDiv * signDiv;
 
   expr.resize(cst.getNumCols(), 0);
   for (unsigned i = 0, e = cst.getNumIds(); i < e; ++i)


        


More information about the Mlir-commits mailing list